Package 'safejoin'
| Title: |
Perform "Safe" Table Joins |
| Description: |
The goal of 'safejoin' is to guarantee that when
performing joins extra rows are not added to your data.
'safejoin' provides a wrapper around 'dplyr::left_join' that
will raise an error when extra rows are unexpectedly added to
your data. This can be useful when working with data where you
expect there to be a many to one relationship but you are not
certain the relationship holds. |
| Authors: |
Sam Edwardes [aut, cre] |
| Maintainer: |
Sam Edwardes <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
0.2.0 |
| Built: |
2026-06-03 06:36:35 UTC |
| Source: |
https://github.com/samedwardes/safejoin |
Help Index